==> aliyun-python-sdk-cas-1.0.8.tar.gz: aliyun-python-sdk-cas-1.0.8/aliyunsdkcas/request/v20200407/DecryptRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcas.endpoint import endpoint_data

class DecryptRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cas', '2020-04-07', 'Decrypt')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_MessageType(self): # String
		return self.get_query_params().get('MessageType')

	def set_MessageType(self, MessageType):  # String
		self.add_query_param('MessageType', MessageType)
	def get_CertIdentifier(self): # String
		return self.get_query_params().get('CertIdentifier')

	def set_CertIdentifier(self, CertIdentifier):  # String
		self.add_query_param('CertIdentifier', CertIdentifier)
	def get_Algorithm(self): # String
		return self.get_query_params().get('Algorithm')

	def set_Algorithm(self, Algorithm):  # String
		self.add_query_param('Algorithm', Algorithm)
	def get_CiphertextBlob(self): # String
		return self.get_query_params().get('CiphertextBlob')

	def set_CiphertextBlob(self, CiphertextBlob):  # String
		self.add_query_param('CiphertextBlob', CiphertextBlob)

==> aliyun-python-sdk-cas-1.0.18.tar.gz: aliyun-python-sdk-cas-1.0.18/aliyunsdkcas/request/v20200407/DecryptRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcas.endpoint import endpoint_data

class DecryptRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cas', '2020-04-07', 'Decrypt','cas')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_MessageType(self): # String
		return self.get_query_params().get('MessageType')

	def set_MessageType(self, MessageType):  # String
		self.add_query_param('MessageType', MessageType)
	def get_CertIdentifier(self): # String
		return self.get_query_params().get('CertIdentifier')

	def set_CertIdentifier(self, CertIdentifier):  # String
		self.add_query_param('CertIdentifier', CertIdentifier)
	def get_Algorithm(self): # String
		return self.get_query_params().get('Algorithm')

	def set_Algorithm(self, Algorithm):  # String
		self.add_query_param('Algorithm', Algorithm)
	def get_CiphertextBlob(self): # String
		return self.get_query_params().get('CiphertextBlob')

	def set_CiphertextBlob(self, CiphertextBlob):  # String
		self.add_query_param('CiphertextBlob', CiphertextBlob)
